BIOMOD.models.out-methods: BIOMOD.models.out getters
Usage
getModelsPrediction(obj, ...)
getModelsPredictionEval(obj, ...)
getModelsEvaluations(obj)
getModelsVarImport(obj)
getModelsOptions(obj)
getModelsInputData(obj, ...)
getModelsBuiltModels(obj)
Arguments
...
extra arguments (see details)
Value
- getModelsPrediction:
{ an array (or a data.frame) containing models predictions over calibrating and testing data (those used for evaluate models)}- getModelsPredictionEval:an
array (or a data.frame) containing models predictions over evaluating data (if referenced / those used for evaluate models) - getModelsEvaluations:an
array containing models variables importances - getModelsVarImport:an
array containing models variables importances - getModelsOptions:a
"BIOMOD.Model.Options" reporting options used to build individual models - getModelsInputData:a
"BIOMOD.formated.data" object containing data used for models building and evavaluation, or a part of this object - getModelsBuiltModels:a character vector giving the names of models succefully computed
code
data.frameitem
- getModelsInputData
'MinMax':'expl.var':