- sp
a vector, SpatialPoints (if presence-only) or
SpatialPointsDataFrame object containing binary data (0 : absence,
1 : presence, NA : indeterminate) for a single species that will be used to
build the species distribution model(s)
- env
a matrix, data.frame, SpatialPointsDataFrame
or RasterStack object containing the explanatory variables
(in columns or layers) that will be used to build the species distribution model(s)
- xy
(optional, default NULL)
If resp.var is a vector, a 2-columns matrix or data.frame
containing the corresponding X and Y coordinates that will be used to build the
species distribution model(s)
- dir.name
a character corresponding to the modeling folder
- sp.name
a character corresponding to the species name
- eval.sp
(optional, default NULL)
A vector, SpatialPoints (if presence-only) or
SpatialPointsDataFrame object containing binary data (0 : absence,
1 : presence, NA : indeterminate) for a single species that will be used to
evaluate the species distribution model(s) with independent data
- eval.env
(optional, default NULL)
A matrix, data.frame, SpatialPointsDataFrame or
RasterStack object containing the explanatory variables (in
columns or layers) that will be used to evaluate the species distribution model(s) with
independent data
- eval.xy
(optional, default NULL)
If resp.var is a vector, a 2-columns matrix or data.frame
containing the corresponding X and Y coordinates that will be used to evaluate
the species distribution model(s) with independent data
- PA.nb.rep
(optional, default 0)
If pseudo-absence selection, an integer corresponding to the number of sets
(repetitions) of pseudo-absence points that will be drawn
- PA.strategy
(optional, default NULL)
If pseudo-absence selection, a character defining the strategy that will be used to
select the pseudo-absence points. Must be random, sre, disk or
user.defined (see Details)
- PA.nb.absences
(optional, default 0)
If pseudo-absence selection, and PA.strategy = 'random' or PA.strategy = 'sre'
or PA.strategy = 'disk', an integer corresponding to the number of pseudo-absence
points that will be selected for each pseudo-absence repetition (true absences included)
- PA.dist.min
(optional, default 0)
If pseudo-absence selection and PA.strategy = 'disk', a numeric defining the
minimal distance to presence points used to make the disk pseudo-absence selection
(in meters, see Details)
- PA.dist.max
(optional, default 0)
If pseudo-absence selection and PA.strategy = 'disk', a numeric defining the
maximal distance to presence points used to make the disk pseudo-absence selection
(in meters, see Details)
- PA.sre.quant
(optional, default 0)
If pseudo-absence selection and PA.strategy = 'sre', a numeric between 0
and 0.5 defining the half-quantile used to make the sre pseudo-absence selection
(see Details)
- PA.user.table
(optional, default NULL)
If pseudo-absence selection and PA.strategy = 'user.defined', a matrix or
data.frame with as many rows as resp.var values, as many columns as
PA.nb.rep, and containing TRUE or FALSE values defining which points
will be used to build the species distribution model(s) for each repetition (see Details)
- na.rm
(optional, default TRUE)
A logical value defining whether points having one or several missing values for
explanatory variables should be removed from the analysis or not
- x
a BIOMOD.formated.data.PA object
- coord
a 2-columns data.frame containing X and Y coordinates for plot
- col
a vector containing colors for plot (default : c('green', 'red',
'orange', 'grey'))
- object
a BIOMOD.formated.data.PA object