This internal biomod2 function allows the user to compute cross-validation
for neural networks in ANN model (see nnet and
BIOMOD_Modeling).
bm_CVnnet(
Input,
Target,
size = c(2, 4, 6, 8),
decay = c(0.001, 0.01, 0.05, 0.1),
maxit = 200,
nbCV = 5,
weights = NULL,
seedval = 555
)A data.frame containing the following elements :
Size : the size
Decay : the decay value
AUC : the corresponding Area Under Curve
complete dataset with explanatory variables
calibration dataset with observed presence / absence
(see parameter ANN$size in BIOMOD_ModelingOptions)
(see parameter ANN$decay in BIOMOD_ModelingOptions)
(see parameter ANN$maxit in BIOMOD_ModelingOptions)
(see parameter ANN$nbCV in BIOMOD_ModelingOptions)
a vector of numeric values corresponding to weights over
calibration lines
an integer value corresponding to the new seed value to be set
Damien Georges
nnet, auc, roc,
BIOMOD_ModelingOptions, BIOMOD_Modeling,
bm_SampleBinaryVector, bm_RunModelsLoop
Other Secundary functions:
bm_BinaryTransformation(),
bm_CrossValidation(),
bm_FindOptimStat(),
bm_MakeFormula(),
bm_PlotEvalBoxplot(),
bm_PlotEvalMean(),
bm_PlotRangeSize(),
bm_PlotResponseCurves(),
bm_PlotVarImpBoxplot(),
bm_PseudoAbsences(),
bm_RunModelsLoop(),
bm_SRE(),
bm_SampleBinaryVector(),
bm_SampleFactorLevels(),
bm_VariablesImportance()