This internal biomod2 function allows to select pseudo-absences according
to 4 different methods : random, sre, disk or user.defined (see Details).
bm_PseudoAbsences(
resp.var,
expl.var,
nb.rep = 1,
strategy = "random",
dist.min = 0,
dist.max = NULL,
nb.absences = NULL,
sre.quant = 0,
user.table = NULL
)bm_PseudoAbsences_user.defined(resp.var, expl.var, ...)
# S4 method for ANY,SpatialPointsDataFrame
bm_PseudoAbsences_user.defined(resp.var, expl.var, user.table)
# S4 method for ANY,RasterStack
bm_PseudoAbsences_user.defined(resp.var, expl.var, user.table)
bm_PseudoAbsences_random(resp.var, expl.var, ...)
# S4 method for ANY,SpatialPointsDataFrame
bm_PseudoAbsences_random(resp.var, expl.var, nb.absences, nb.rep)
# S4 method for ANY,RasterStack
bm_PseudoAbsences_random(resp.var, expl.var, nb.absences, nb.rep)
bm_PseudoAbsences_sre(resp.var, expl.var, ...)
# S4 method for ANY,SpatialPointsDataFrame
bm_PseudoAbsences_sre(resp.var, expl.var, sre.quant, nb.absences, nb.rep)
# S4 method for ANY,RasterStack
bm_PseudoAbsences_sre(resp.var, expl.var, sre.quant, nb.absences, nb.rep)
bm_PseudoAbsences_disk(resp.var, expl.var, ...)
# S4 method for ANY,SpatialPointsDataFrame
bm_PseudoAbsences_disk(
resp.var,
expl.var,
dist.min,
dist.max,
nb.absences,
nb.rep
)
# S4 method for ANY,RasterStack
bm_PseudoAbsences_disk(
resp.var,
expl.var,
dist.min,
dist.max,
nb.absences,
nb.rep
)
A list containing the following elements :
xy : the coordinates of the species observations
sp : the values of the species observations (0, 1 or NA)
env : the explanatory variables
pa.tab : the corresponding table of selected pseudo-absences (indicated by
TRUE or FALSE)
a vector, SpatialPoints or
SpatialPointsDataFrame object containing binary data (0 : absence,
1 : presence, NA : indeterminate) for a single species that will be used to
find the pseudo-absences
a matrix, data.frame, SpatialPointsDataFrame
or RasterStack object containing the explanatory variables (in
columns or layers) that will be used to find the pseudo-absences
an integer corresponding to the number of sets (repetitions) of
pseudo-absence points that will be drawn
a character corresponding to the pseudo-absence selection strategy,
must be among random, sre, disk or user.defined
(optional, default 0)
If strategy = 'disk', a numeric defining the minimal distance to presence points
used to make the disk pseudo-absence selection (in meters)
(optional, default NULL)
If strategy = 'disk', a numeric defining the maximal distance to presence points
used to make the disk pseudo-absence selection (in meters)
(optional, default NULL)
If strategy = 'random' or strategy = 'sre' or strategy = 'disk', an
integer corresponding to the number of pseudo-absence points that will be selected for
each pseudo-absence repetition (true absences included)
(optional, default 0)
If strategy = 'sre', a numeric between 0 and 0.5 defining the
half-quantile used to make the sre pseudo-absence selection (see bm_SRE)
(optional, default NULL)
If strategy = 'user.defined', a matrix or data.frame with as many rows as
resp.var values, as many columns as nb.rep, and containing TRUE or
FALSE values defining which points will be used to build the species distribution
model(s) for each repetition
(optional, one or several of the following arguments depending on the selected method))
Wilfried Thuiller, Damien Georges
Concerning random selection :
The idea is to select pseudo-absences randomly in spatial locations where the species has not
been sampled. This method is the simplest one and the most appropriate if lacking information
about the presence sampling (non-exhaustive, biased sampling, etc).
Concerning SRE selection :
The idea is to select pseudo-absences in spatial locations whose environmental conditions are
different from those of the presence points. This method is appropriate when most of the
environmental space of the species has been sampled.
Concerning disk selection :
The idea is to select pseudo-absences, not too close from presence points, but not too far
away either. This method is appropriate when most of the spatial range of the species has
been sampled.
Concerning user defined selection :
The user can provide pseudo-absences locations through a table containing spatial locations
in rows, pseudo-absences repetitions in columns, and TRUE/FALSE values indicating
whether each point is to be considered as pseudo-absence or not for each dataset.
BIOMOD.formated.data.PA, BIOMOD_FormatingData
Other Secundary functions:
bm_BinaryTransformation(),
bm_CVnnet(),
bm_FindOptimStat(),
bm_MakeFormula(),
bm_PlotEvalBoxplot(),
bm_PlotEvalMean(),
bm_PlotRangeSize(),
bm_PlotResponseCurves(),
bm_PlotVarImpBoxplot(),
bm_RunModelsLoop(),
bm_SRE(),
bm_SampleBinaryVector(),
bm_SampleFactorLevels(),
bm_VariablesImportance()