BIOMOD.models.out,
BIOMOD.projection.out or BIOMOD.ensemble.models.out objectsThese functions allow the user to easily retrieve informations stored in the different biomod2 objects from the different modeling steps, such as modeling options and formated data, models used or not, predictions, evaluations, variables importance.
# S4 method for BIOMOD.models.out
get_options(obj)# S4 method for BIOMOD.models.out
get_calib_lines(obj, as.data.frame = FALSE, ...)
# S4 method for BIOMOD.models.out
get_formal_data(obj, subinfo = NULL)
# S4 method for BIOMOD.models.out
get_predictions(
obj,
as.data.frame = FALSE,
evaluation = FALSE,
full.name = NULL,
model = NULL,
run.eval = NULL,
data.set = NULL
)
# S4 method for BIOMOD.models.out
get_built_models(obj, ...)
# S4 method for BIOMOD.models.out
get_evaluations(obj, as.data.frame = FALSE, ...)
# S4 method for BIOMOD.models.out
get_variables_importance(obj, as.data.frame = FALSE, ...)
# S4 method for BIOMOD.projection.out
get_projected_models(obj)
# S4 method for BIOMOD.projection.out
free(obj)
# S4 method for BIOMOD.projection.out
get_predictions(
obj,
as.data.frame = FALSE,
full.name = NULL,
model = NULL,
run.eval = NULL,
data.set = NULL
)
# S4 method for BIOMOD.ensemble.models.out
get_formal_data(obj, subinfo = NULL)
# S4 method for BIOMOD.ensemble.models.out
get_built_models(obj, ...)
# S4 method for BIOMOD.ensemble.models.out
get_needed_models(obj, selected.models = "all", ...)
# S4 method for BIOMOD.ensemble.models.out
get_kept_models(obj, model, ...)
# S4 method for BIOMOD.ensemble.models.out
get_predictions(
obj,
as.data.frame = FALSE,
evaluation = FALSE,
full.name = NULL
)
# S4 method for BIOMOD.ensemble.models.out
get_built_models(obj, ...)
# S4 method for BIOMOD.ensemble.models.out
get_evaluations(obj, as.data.frame = FALSE, ...)
# S4 method for BIOMOD.ensemble.models.out
get_variables_importance(obj, as.data.frame = FALSE, ...)
get_optionsa
BIOMOD.stored.models.options-class object from the
models.options slot of a BIOMOD.models.out-class
object
get_calib_linesa
BIOMOD.stored.array-class object from the calib.lines
slot of a BIOMOD.models.out object
get_projected_modelsa vector from the
models.projected slot of a BIOMOD.projection.out
object
get_predictionsa BIOMOD.stored.data object
from the proj.out slot of a BIOMOD.models.out,
BIOMOD.projection.out or
BIOMOD.ensemble.models.out object
get_needed_modelsa vector containing names of the
needed models of a BIOMOD.ensemble.models.out object
get_kept_modelsa vector containing names of the kept
models of a BIOMOD.ensemble.models.out object
get_formal_datadepending on the subinfo parameter :
NULLa BIOMOD.stored.formated.data-class (or
BIOMOD.stored.models.out-class) object from the
formated.input.data (or models.out) slot of a
BIOMOD.models.out (or
BIOMOD.ensemble.models.out) object
expl.var.namesa vector from the
expl.var.names slot of a BIOMOD.models.out or
BIOMOD.ensemble.models.out object
resp.vara vector from the data.species slot
of the formated.input.data slot of a
BIOMOD.models.out or
BIOMOD.ensemble.models.out object
expl.vara data.frame from the data.env.var
slot of the formated.input.data slot of a
BIOMOD.models.out or
BIOMOD.ensemble.models.out object
MinMaxa list of minimum and maximum values (or
levels if factorial) of variable contained in the data.env.var
slot of the formated.input.data slot of a
BIOMOD.models.out or
BIOMOD.ensemble.models.out object
eval.resp.vara vector from the
eval.data.species slot of the formated.input.data slot of
a BIOMOD.models.out or
BIOMOD.ensemble.models.out object
eval.expl.vara data.frame from the
eval.data.env.var slot of the formated.input.data slot of
a BIOMOD.models.out or
BIOMOD.ensemble.models.out object
get_built_modelsa vector from the
models.computed slot (or em.computed) of a
BIOMOD.models.out (or
BIOMOD.ensemble.models.out) object
get_evaluationsa
BIOMOD.stored.array-class (or
matrix) from the models.evaluation slot (or
model_evaluation of each model in em.computed) of a
BIOMOD.models.out (or
BIOMOD.ensemble.models.out) object
get_variables_importancea
BIOMOD.stored.array-class from
the variables.importance slot (or model_variables_importance
of each model in em.models) of a BIOMOD.models.out
(or BIOMOD.ensemble.models.out) object
a BIOMOD.models.out, BIOMOD.projection.out or
BIOMOD.ensemble.models.out object
a logical defining whether output should be returned as
data.frame or array object
a character corresponding to the information to be extracted, must be
among NULL, expl.var.names, resp.var, expl.var, MinMax,
eval.resp.var, eval.expl.var (see Details)
a logical defining whether evaluation data should be used or not
a vector containing model names to be kept, must be either all
or a sub-selection of model names
a character corresponding to the model name, must be either GLM,
GBM, GAM, CTA, ANN, SRE, FDA, MARS,
RF, MAXENT.Phillips, MAXENT.Phillips.2
a vector containing repetition set to be loaded, must be among
RUN1, RUN2, ..., Full
a vector containing pseudo-absence set to be loaded, must be among
PA1, PA2, ...
a vector containing names of the needed models of a
BIOMOD.ensemble.models.out object
(optional, one or several of the following arguments depending on the selected function))
Damien Georges
BIOMOD.models.out, BIOMOD.projection.out,
BIOMOD.ensemble.models.out
Other Toolbox functions:
getters.bm,
load_stored_object(),
predict.bm,
predict.em,
predict2.bm,
predict2.em